<?php
namespace WSCOMUN\CATASTRO;
use Exception;
use SoapVar;
use DateTime;
use ArrayObject;
use stdClass;

/**
 *
 * @author pbelenguer
 * @author pascual_dav@externos.gva.es
 *
 */
class ComposerCatastro
{
	/**
	 * Contantes para los NS
	 */
	private static $NAMESPACE_SCSP_ESPECIFICO = 'http://intermediacion.redsara.es/scsp/esquemas/datosespecificos';

	/**
	 * Convierte un array en un arbol de objetos
	 *
	 * @access	protected
	 * @param  	array		$array	Array a convertir
	 * @return	stdClass	Devuelve el objeto equivalente
	*/
	protected function array2ObjectTree($array)
	{
		if (is_numeric(key($array)))
		{
			foreach ($array as $key => $value)
			{
				$array[$key] = $this->array_to_objecttree($value);
			}
			return $array;
		}
		$Object = new stdClass;
		foreach ($array as $key => $value)
		{
			if (is_array($value))
			{
				$Object->$key = $this->array_to_objecttree($value);
			}
			else
			{
				$Object->$key = $value;
			}
		}
		return $Object;
	}//Fin array2ObjectTree

	/**
	 * Convierte un objeto en un array asociativo
	 *
	 * @access	private
	 * @param  	array		$array	Array a convertir
	 * @return	stdClass	Devuelve el objeto equivalente
	 */
	protected function objectTree2array($obj)
	{
		if (is_array($obj) || is_object($obj))
		{
			$result = array();
			foreach ($obj as $key => $value)
			{
				$result[$key] = $this->objectTree2array($value);
			}
			return $result;
		}
		return $obj;
	}//Fin objectTree2array



	private function __anyType_SoapVar($childData, $fieldName, $namespace) {
//var_dump($childData);
		if (is_a($childData, 'DateTime')) {
//var_dump($childData);
//die('DateTime: ' . $fieldName);
			return new SoapVar($childData->format(DateTime::ATOM), XSD_DATETIME, 'dateTime', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
		} elseif (is_int($childData)) {
//die('Integer: ' . $fieldName);
			return new SoapVar($childData, XSD_INTEGER, null, null, $fieldName, $namespace);
		}

//die('Generic: ' . $fieldName);
		return new SoapVar($childData, XSD_STRING, 'string', 'http://www.w3.org/2001/XMLSchema', $fieldName, $namespace);
	}

	private function __basic_SoapVar($childData, $basicType, $fieldName, $namespace) {
		switch ($basicType) {
			case XSD_DATETIME:
				return new SoapVar($childData->format(DateTime::ATOM), $basicType, null, null, $fieldName, $namespace);

			default:
				return new SoapVar($childData, $basicType, null, null, $fieldName, $namespace);
		}
	}

	public function __doChild($parentTag, $vData, $fieldName, $type, $namespace, $minOccurs, $maxOccurs)
	{
//echo("__doChild: $type [$fieldName]<br>");
		$fieldSet = isset($vData[$fieldName]);
		if (!$fieldSet) {
			if ($minOccurs > 0) {
				throw new Exception("No se ha encontrado el subcampo obligatorio '" . $fieldName . '"');
			} else {
				return true;
			}
		}

		$vChildData = $vData[$fieldName];
		if ($maxOccurs == 1) {
			$vChildData = array( $vData[$fieldName] );
		} else {
			if ($maxOccurs != 'unbounded') {
				if ($maxOccurs > sizeof($vChildData)) {
					throw new Exception("El campo '" . $fieldName . '" no tiene tantas ocurrencias como se esperaban');
				}
			} else {
//				var_dump($vChildData);die;
			}
		}

//var_dump(array_keys($vChildData));
		for ($iIter=0; $iIter < sizeof($vChildData); $iIter++) {
			$childData = $vChildData[$iIter];

			if ((($minOccurs > 0) && $fieldSet) || $fieldSet) {
				if (isset($this->vBasics[$type])) {

					$basicType = $this->vBasics[$type];
//echo("Basic: $type | $basicType [$fieldName]<br>");
					if ($basicType !== XSD_ANYTYPE) {
						$childSOAP = $this->__basic_SoapVar($childData, $basicType, $fieldName, $namespace);
					} else {
						$childSOAP = $this->__anyType_SoapVar($childData, $fieldName, $namespace);
					}
					$parentTag->append( $childSOAP );
//					return true;

				} else { //if (isset($this->$funcName)) {
					$funcName = '__cde__' . $type . '_full';
//echo("FuncName: $funcName | $type [$fieldName]<br>");

					$childSOAP = $this->$funcName($childData, $fieldName, $namespace);
					$parentTag->append( $childSOAP );
//					return true;
				}
			} else {
				return false;
			}

		}

		// TODO: HACER EL MULTIAPARICION!!!
		/*
		var_dump($parentTag);
		var_dump($vData);
		var_dump($fieldName);
		var_dump($type);
		var_dump($namespace);
		var_dump($minOccurs);
		var_dump($maxOccurs);

		die("FAIL!!!");
		*/

		return true;
	}



	public function doIt($vData) {
//		die('112');
		return $this->__cde__DatosEspecificos_full($vData, 'DatosEspecificos', self::$NAMESPACE_SCSP_ESPECIFICO);
	}




	/******************************************/
	/********** CODIGO AUTO-GENERADO **********/
	/******************************************/



private function __cde__DatosEspecificos($vData, $fieldName, $namespace)
{
//die('33');
	$myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'DatosEntrada', 'DatosEntrada', $namespace, 0, 1);	// name="DatosEntrada" type="DatosEntrada" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'listaBienesInmuebles', 'listaBienesInmuebles', $namespace, 0, 1);	// name="listaBienesInmuebles" type="listaBienesInmuebles" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'Estado', 'Estado', $namespace, 0, 1);	// name="Estado" type="Estado" minOccurs="0"
  return $myLevel;
}

private function __cde__DatosEspecificos_full($vData, $fieldName, $namespace)
{
//die('222');
  $myLevel = $this->__cde__DatosEspecificos($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__DatosEntrada($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'referenciaCatastral', 'rcl', $namespace, 0, 1);	// name="referenciaCatastral" type="rcl" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'referenciaRustica', 'rrl', $namespace, 0, 1);	// name="referenciaRustica" type="rrl" minOccurs="0"
  return $myLevel;
}

private function __cde__DatosEntrada_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__DatosEntrada($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__loine($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cp', 'cp', $namespace, 1, 1);	// name="cp" type="cp" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'cm', 'cm', $namespace, 1, 1);	// name="cm" type="cm" minOccurs="1"
  return $myLevel;
}

private function __cde__loine_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__loine($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__rcl($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'pc1', 'pcatastral1', $namespace, 1, 1);	// name="pc1" type="pcatastral1" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'pc2', 'pcatastral2', $namespace, 1, 1);	// name="pc2" type="pcatastral2" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'car', 'car', $namespace, 0, 1);	// name="car" type="car" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cc1', 'cc', $namespace, 0, 1);	// name="cc1" type="cc" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cc2', 'cc', $namespace, 0, 1);	// name="cc2" type="cc" minOccurs="0"
  return $myLevel;
}

private function __cde__rcl_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__rcl($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__rrl($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'localizacionINE', 'loine', $namespace, 1, 1);	// name="localizacionINE" type="loine" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'cpp', 'cpp', $namespace, 1, 1);	// name="cpp" type="cpp" minOccurs="1"
  return $myLevel;
}

private function __cde__rrl_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__rrl($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__pc($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'pc1', 'pcatastral1', $namespace, 1, 1);	// name="pc1" type="pcatastral1" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'pc2', 'pcatastral2', $namespace, 1, 1);	// name="pc2" type="pcatastral2" minOccurs="1"
  return $myLevel;
}

private function __cde__pc_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__pc($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__listaBienesInmuebles($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();

  $fnInt_datosInmueble = function($vData, $fieldName, $namespace)
  {
    $myLevel = new ArrayObject();
    $this->__doChild($myLevel, $vData, 'BienInmuebleRustico', 'bir', $namespace, 0, 1);	// name="BienInmuebleRustico" type="bir" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'listaTitulares', 'ltit', $namespace, 0, 1);	// name="listaTitulares" type="ltit" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'finca', 'fincared', $namespace, 0, 1);	// name="finca" type="fincared" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'listaConstrucciones', 'lconsr', $namespace, 0, 1);	// name="listaConstrucciones" type="lconsr" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'listaSubparcelas', 'lspr', $namespace, 0, 1);	// name="listaSubparcelas" type="lspr" minOccurs="0"
    return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
  };
  $this->__doPrivateChild($myLevel, $vData, 'datosInmueble', $fnInt_datosInmueble, $namespace, 1, unbounded);	// name="datosInmueble" minOccurs="1"
  return $myLevel;
}

private function __cde__listaBienesInmuebles_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__listaBienesInmuebles($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__Estado($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'CodigoEstado', '101', $namespace, 0, 1);	// name="CodigoEstado" type="101" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'CodigoEstadoSecundario', '101', $namespace, 0, 1);	// name="CodigoEstadoSecundario" type="101" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'LiteralError', '101', $namespace, 0, 1);	// name="LiteralError" type="101" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'TiempoEstimadoRespuesta', '135', $namespace, 0, 1);	// name="TiempoEstimadoRespuesta" type="135" minOccurs="0"
  return $myLevel;
}

private function __cde__Estado_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__Estado($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__cpp($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cpo', 'cpo', $namespace, 1, 1);	// name="cpo" type="cpo" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'cpa', 'cpa', $namespace, 0, 1);	// name="cpa" type="cpa" minOccurs="0"
  return $myLevel;
}

private function __cde__cpp_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__cpp($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__err($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cod', 'stringnb', $namespace, 1, 1);	// name="cod" type="stringnb" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'des', 'stringnb', $namespace, 1, 1);	// name="des" type="stringnb" minOccurs="1"
  return $myLevel;
}

private function __cde__err_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__err($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__bir($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'idine', 'idine', $namespace, 1, 1);	// name="idine" type="idine" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'ldt', 'stringnb', $namespace, 0, 1);	// name="ldt" type="stringnb" minOccurs="0"

  $fnInt_debi = function($vData, $fieldName, $namespace)
  {
    $myLevel = new ArrayObject();
    $this->__doChild($myLevel, $vData, 'avc', 'xs:gYear', $namespace, 0, 1);	// name="avc" type="xs:gYear" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'vcat', 'vcat', $namespace, 0, 1);	// name="vcat" type="vcat" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'vcs', 'vcat', $namespace, 0, 1);	// name="vcs" type="vcat" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'vcc', 'vcat', $namespace, 0, 1);	// name="vcc" type="vcat" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'luso', 'lusoovccd', $namespace, 0, 1);	// name="luso" type="lusoovccd" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'sfc', 'supg', $namespace, 0, 1);	// name="sfc" type="supg" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'cpt', 'cpt', $namespace, 0, 1);	// name="cpt" type="cpt" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'ant', 'xs:gYear', $namespace, 0, 1);	// name="ant" type="xs:gYear" minOccurs="0"
    return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
  };
  $this->__doPrivateChild($myLevel, $vData, 'debi', $fnInt_debi, $namespace, 0, 1);	// name="debi" minOccurs="0"

  $fnInt_lcol = function($vData, $fieldName, $namespace)
  {
    $myLevel = new ArrayObject();

    $fnInt_col = function($vData, $fieldName, $namespace)
    {
      $myLevel = new ArrayObject();
      $this->__doChild($myLevel, $vData, 'rcof', 'rcof', $namespace, 0, 1);	// name="rcof" type="rcof" minOccurs="0"
      $this->__doChild($myLevel, $vData, 'idp_out', 'idp_out', $namespace, 0, 1);	// name="idp_out" type="idp_out" minOccurs="0"
      $this->__doChild($myLevel, $vData, 'sup', 'supp', $namespace, 0, 1);	// name="sup" type="supp" minOccurs="0"
      $this->__doChild($myLevel, $vData, 'lloc', 'stringnb', $namespace, 0, 1);	// name="lloc" type="stringnb" minOccurs="0"
      $this->__doChild($myLevel, $vData, 'dtrus', 'dtrus', $namespace, 0, 1);	// name="dtrus" type="dtrus" minOccurs="0"
      return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    };
    $this->__doPrivateChild($myLevel, $vData, 'col', $fnInt_col, $namespace, 1, unbounded);	// name="col" minOccurs="1"
    return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
  };
  $this->__doPrivateChild($myLevel, $vData, 'lcol', $fnInt_lcol, $namespace, 0, 1);	// name="lcol" minOccurs="0"
  return $myLevel;
}

private function __cde__bir_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__bir($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__bi($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'idbi', 'idbi', $namespace, 0, 1);	// name="idbi" type="idbi" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'idcat', 'idcat', $namespace, 0, 1);	// name="idcat" type="idcat" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'idine', 'idine', $namespace, 0, 1);	// name="idine" type="idine" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'idreg', 'idreg', $namespace, 0, 1);	// name="idreg" type="idreg" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'idbis', 'idbis', $namespace, 0, 1);	// name="idbis" type="idbis" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'rc', 'rcl', $namespace, 0, 1);	// name="rc" type="rcl" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'idad', 'idad', $namespace, 0, 1);	// name="idad" type="idad" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'tbi', 'tbi', $namespace, 0, 1);	// name="tbi" type="tbi" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dt', 'dt', $namespace, 0, 1);	// name="dt" type="dt" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ldt', 'stringnb', $namespace, 0, 1);	// name="ldt" type="stringnb" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'inrbi', 'inrbi', $namespace, 0, 1);	// name="inrbi" type="inrbi" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'debi', 'debi', $namespace, 0, 1);	// name="debi" type="debi" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dcbl', 'dcbl', $namespace, 0, 1);	// name="dcbl" type="dcbl" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'spas', 'spas', $namespace, 0, 1);	// name="spas" type="spas" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'rep', 'repr', $namespace, 0, 1);	// name="rep" type="repr" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'lcol', 'lcol', $namespace, 0, 1);	// name="lcol" type="lcol" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'lcons', 'lcons', $namespace, 0, 1);	// name="lcons" type="lcons" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'evbi', 'evbi', $namespace, 0, 1);	// name="evbi" type="evbi" minOccurs="0"
  return $myLevel;
}

private function __cde__bi_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__bi($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idbi($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cn', 'cn', $namespace, 1, 1);	// name="cn" type="cn" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'rc', 'rcl', $namespace, 1, 1);	// name="rc" type="rcl" minOccurs="1"
  return $myLevel;
}

private function __cde__idbi_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idbi($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idcat($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $myLevel = $this->__cde__idbi($vData, $fieldName, $namespace);
  $this->__doChild($myLevel, $vData, 'locat', 'locat', $namespace, 1, 1);	// name="locat" type="locat" minOccurs="1"
  return $myLevel;
}

private function __cde__idcat_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idcat($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__locat($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cd', 'cd', $namespace, 1, 1);	// name="cd" type="cd" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'cmc', 'cmc', $namespace, 1, 1);	// name="cmc" type="cmc" minOccurs="1"
  return $myLevel;
}

private function __cde__locat_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__locat($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idine($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $myLevel = $this->__cde__idbi($vData, $fieldName, $namespace);
  $this->__doChild($myLevel, $vData, 'loine', 'loine', $namespace, 1, 1);	// name="loine" type="loine" minOccurs="1"
  return $myLevel;
}

private function __cde__idine_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idine($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idreg($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'locat', 'locat', $namespace, 1, 1);	// name="locat" type="locat" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'rcl', 'rcl', $namespace, 0, 1);	// name="rcl" type="rcl" minOccurs="0"
  return $myLevel;
}

private function __cde__idreg_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idreg($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idbis($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  if (isset($vData['idbic'])) {
    $this->__doChild($myLevel, $vData, 'idbic', 'idbic', $namespace, 1, 1);	// name="idbic" type="idbic" minOccurs="1"
  } elseif (isset($vData['idbip'])) {
    $this->__doChild($myLevel, $vData, 'idbip', 'idbip', $namespace, 1, 1);	// name="idbip" type="idbip" minOccurs="1"
  } else {
    throw new Exception('Elegir opcion');
  }
  return $myLevel;
}

private function __cde__idbis_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idbis($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idbic($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cn', 'cn', $namespace, 1, 1);	// name="cn" type="cn" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'lrc', 'lrc', $namespace, 1, 1);	// name="lrc" type="lrc" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'erc', 'erc', $namespace, 1, 1);	// name="erc" type="erc" minOccurs="1"
  return $myLevel;
}

private function __cde__idbic_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idbic($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idbip($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cn', 'cn', $namespace, 1, 1);	// name="cn" type="cn" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'irc', 'irc', $namespace, 1, 1);	// name="irc" type="irc" minOccurs="1"
  return $myLevel;
}

private function __cde__idbip_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idbip($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idad($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'nfbi', 'nfbi', $namespace, 0, 1);	// name="nfbi" type="nfbi" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'iia', 'iia', $namespace, 0, 1);	// name="iia" type="iia" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'nfr', 'nfr', $namespace, 0, 1);	// name="nfr" type="nfr" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'noedh', 'noedh', $namespace, 0, 1);	// name="noedh" type="noedh" minOccurs="0"
  return $myLevel;
}

private function __cde__idad_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idad($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__nfr($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'rp', 'rp', $namespace, 1, 1);	// name="rp" type="rp" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'sc', 'sc', $namespace, 1, 1);	// name="sc" type="sc" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'fr', 'fr', $namespace, 1, 1);	// name="fr" type="fr" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'sfr', 'sfr', $namespace, 0, 1);	// name="sfr" type="sfr" minOccurs="0"
  return $myLevel;
}

private function __cde__nfr_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__nfr($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__rp($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cp', 'cp', $namespace, 1, 1);	// name="cp" type="cp" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'crp', 'crp', $namespace, 1, 1);	// name="crp" type="crp" minOccurs="1"
  return $myLevel;
}

private function __cde__rp_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__rp($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__dt($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'loine', 'loine', $namespace, 0, 1);	// name="loine" type="loine" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cmc', 'cmc', $namespace, 0, 1);	// name="cmc" type="cmc" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'np', 'np', $namespace, 0, 1);	// name="np" type="np" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'nm', 'nm', $namespace, 0, 1);	// name="nm" type="nm" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'nem', 'nem', $namespace, 0, 1);	// name="nem" type="nem" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'lourb', 'lourb', $namespace, 0, 1);	// name="lourb" type="lourb" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'lorus', 'lorus', $namespace, 0, 1);	// name="lorus" type="lorus" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'locs', 'locs', $namespace, 0, 1);	// name="locs" type="locs" minOccurs="0"
  return $myLevel;
}

private function __cde__dt_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__dt($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lourb($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'dir', 'dir', $namespace, 0, 1);	// name="dir" type="dir" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'bl', 'bq', $namespace, 0, 1);	// name="bl" type="bq" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'loint', 'loint', $namespace, 0, 1);	// name="loint" type="loint" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dp', 'dp', $namespace, 0, 1);	// name="dp" type="dp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dm', 'dm', $namespace, 0, 1);	// name="dm" type="dm" minOccurs="0"
  return $myLevel;
}

private function __cde__lourb_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lourb($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__dir($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cv', 'cv', $namespace, 0, 1);	// name="cv" type="cv" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'tv', 'tv', $namespace, 1, 1);	// name="tv" type="tv" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'nv', 'nv', $namespace, 1, 1);	// name="nv" type="nv" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'pnp', 'pnp', $namespace, 0, 1);	// name="pnp" type="pnp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'plp', 'plp', $namespace, 0, 1);	// name="plp" type="plp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'snp', 'snp', $namespace, 0, 1);	// name="snp" type="snp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'slp', 'slp', $namespace, 0, 1);	// name="slp" type="slp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'km', 'km', $namespace, 0, 1);	// name="km" type="km" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'td', 'dne', $namespace, 0, 1);	// name="td" type="dne" minOccurs="0"
  return $myLevel;
}

private function __cde__dir_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__dir($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__loint($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'bq', 'bq', $namespace, 0, 1);	// name="bq" type="bq" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'es', 'es', $namespace, 0, 1);	// name="es" type="es" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'pt', 'pt', $namespace, 0, 1);	// name="pt" type="pt" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'pu', 'pu', $namespace, 0, 1);	// name="pu" type="pu" minOccurs="0"
  return $myLevel;
}

private function __cde__loint_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__loint($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lorus($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cma', 'cma', $namespace, 0, 1);	// name="cma" type="cma" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'czc', 'czc', $namespace, 0, 1);	// name="czc" type="czc" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cpp', 'cpp', $namespace, 0, 1);	// name="cpp" type="cpp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'npa', 'npa', $namespace, 0, 1);	// name="npa" type="npa" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cpaj', 'cpaj', $namespace, 0, 1);	// name="cpaj" type="cpaj" minOccurs="0"
  return $myLevel;
}

private function __cde__lorus_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lorus($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__locs($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  if (isset($vData['lous'])) {
    $this->__doChild($myLevel, $vData, 'lous', 'lous', $namespace, 1, 1);	// name="lous" type="lous" minOccurs="1"
  } elseif (isset($vData['lors'])) {
    $this->__doChild($myLevel, $vData, 'lors', 'lors', $namespace, 1, 1);	// name="lors" type="lors" minOccurs="1"
  } else {
    throw new Exception('Elegir opcion');
  }
  return $myLevel;
}

private function __cde__locs_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__locs($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lous($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'lourb', 'lourb', $namespace, 1, 1);	// name="lourb" type="lourb" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'lorus', 'lorus', $namespace, 0, 1);	// name="lorus" type="lorus" minOccurs="0"
  return $myLevel;
}

private function __cde__lous_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lous($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lors($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'lorus', 'lorus', $namespace, 1, 1);	// name="lorus" type="lorus" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'lourb', 'lourb', $namespace, 0, 1);	// name="lourb" type="lourb" minOccurs="0"
  return $myLevel;
}

private function __cde__lors_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lors($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__inrbi($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'sup', 'sup', $namespace, 0, 1);	// name="sup" type="sup" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ciur', 'ciur', $namespace, 0, 1);	// name="ciur" type="ciur" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'tcons', 'tcons', $namespace, 0, 1);	// name="tcons" type="tcons" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'tnfr', 'tnfr', $namespace, 0, 1);	// name="tnfr" type="tnfr" minOccurs="0"
  return $myLevel;
}

private function __cde__inrbi_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__inrbi($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__debi($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'pvd', 'vcat', $namespace, 0, 1);	// name="pvd" type="vcat" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'opvd', 'opvd', $namespace, 0, 1);	// name="opvd" type="opvd" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'pav', 'vcat', $namespace, 0, 1);	// name="pav" type="vcat" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'afv', 'xs:gYear', $namespace, 0, 1);	// name="afv" type="xs:gYear" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'itp', 'itp', $namespace, 0, 1);	// name="itp" type="itp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'noe', 'noe', $namespace, 0, 1);	// name="noe" type="noe" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'avc', 'xs:gYear', $namespace, 0, 1);	// name="avc" type="xs:gYear" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'vcat', 'vcat', $namespace, 0, 1);	// name="vcat" type="vcat" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'vcs', 'vcat', $namespace, 0, 1);	// name="vcs" type="vcat" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'vcc', 'vcat', $namespace, 0, 1);	// name="vcc" type="vcat" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'bl', 'vcat', $namespace, 0, 1);	// name="bl" type="vcat" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'uso', 'uso', $namespace, 0, 1);	// name="uso" type="uso" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'luso', 'luso', $namespace, 0, 1);	// name="luso" type="luso" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'bru', 'bru', $namespace, 0, 1);	// name="bru" type="bru" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'sfc', 'supg', $namespace, 0, 1);	// name="sfc" type="supg" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'sfs', 'supg', $namespace, 0, 1);	// name="sfs" type="supg" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cpt', 'cpt', $namespace, 0, 1);	// name="cpt" type="cpt" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ant', 'xs:gYear', $namespace, 0, 1);	// name="ant" type="xs:gYear" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'bimp', 'vcat', $namespace, 0, 1);	// name="bimp" type="vcat" minOccurs="0"
  return $myLevel;
}

private function __cde__debi_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__debi($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__bru($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'bvc', 'vcat', $namespace, 1, 1);	// name="bvc" type="vcat" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'bcl', 'cbon', $namespace, 1, 1);	// name="bcl" type="cbon" minOccurs="1"
  return $myLevel;
}

private function __cde__bru_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__bru($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__dcbl($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'vb', 'vcat', $namespace, 0, 1);	// name="vb" type="vcat" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cvb', 'cvb', $namespace, 0, 1);	// name="cvb" type="cvb" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'evcr', 'xs:gYear', $namespace, 0, 1);	// name="evcr" type="xs:gYear" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'vcr', 'vcat', $namespace, 0, 1);	// name="vcr" type="vcat" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ert', 'xs:gYear', $namespace, 0, 1);	// name="ert" type="xs:gYear" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'erp', 'xs:gYear', $namespace, 0, 1);	// name="erp" type="xs:gYear" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'per', 'per', $namespace, 0, 1);	// name="per" type="per" minOccurs="0"
  return $myLevel;
}

private function __cde__dcbl_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__dcbl($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__drsp($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'dr', 'dr', $namespace, 1, 1);	// name="dr" type="dr" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'nt', 'nt', $namespace, 1, 1);	// name="nt" type="nt" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'tt', 'tt', $namespace, 1, 1);	// name="tt" type="tt" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'ct', 'ct', $namespace, 0, 1);	// name="ct" type="ct" minOccurs="0"
  return $myLevel;
}

private function __cde__drsp_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__drsp($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idps($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  if (isset($vData['nif'])) {
    $this->__doChild($myLevel, $vData, 'nif', 'nif', $namespace, 1, 1);	// name="nif" type="nif" minOccurs="1"
  } elseif (isset($vData['cii'])) {
    $this->__doChild($myLevel, $vData, 'cii', 'cii', $namespace, 1, 1);	// name="cii" type="cii" minOccurs="1"
  } else {
    throw new Exception('Elegir opcion');
  }
  $this->__doChild($myLevel, $vData, 'nom', 'nom', $namespace, 1, 1);	// name="nom" type="nom" minOccurs="1"
  return $myLevel;
}

private function __cde__idps_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idps($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__spas($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'drsp', 'drsp', $namespace, 0, 1);	// name="drsp" type="drsp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'idps', 'idps', $namespace, 0, 1);	// name="idps" type="idps" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'df', 'dfsp', $namespace, 0, 1);	// name="df" type="dfsp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cony', 'cony', $namespace, 0, 1);	// name="cony" type="cony" minOccurs="0"
  return $myLevel;
}

private function __cde__spas_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__spas($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__dfsp($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'loine', 'loine', $namespace, 0, 1);	// name="loine" type="loine" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cmc', 'cmc', $namespace, 0, 1);	// name="cmc" type="cmc" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'np', 'np', $namespace, 0, 1);	// name="np" type="np" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'nm', 'nm', $namespace, 0, 1);	// name="nm" type="nm" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'nem', 'nem', $namespace, 0, 1);	// name="nem" type="nem" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dir', 'dir', $namespace, 0, 1);	// name="dir" type="dir" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'loint', 'loint', $namespace, 0, 1);	// name="loint" type="loint" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'pos', 'pos', $namespace, 0, 1);	// name="pos" type="pos" minOccurs="0"
  return $myLevel;
}

private function __cde__dfsp_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__dfsp($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__df($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'loine', 'loine', $namespace, 0, 1);	// name="loine" type="loine" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cmc', 'cmc', $namespace, 0, 1);	// name="cmc" type="cmc" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'np', 'np', $namespace, 0, 1);	// name="np" type="np" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'nm', 'nm', $namespace, 0, 1);	// name="nm" type="nm" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'nem', 'nem', $namespace, 0, 1);	// name="nem" type="nem" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dir', 'dir', $namespace, 0, 1);	// name="dir" type="dir" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'loint', 'loint', $namespace, 0, 1);	// name="loint" type="loint" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'pos', 'pos', $namespace, 0, 1);	// name="pos" type="pos" minOccurs="0"
  return $myLevel;
}

private function __cde__df_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__df($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__pos($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'dp', 'dp', $namespace, 1, 1);	// name="dp" type="dp" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'ac', 'ac', $namespace, 0, 1);	// name="ac" type="ac" minOccurs="0"
  return $myLevel;
}

private function __cde__pos_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__pos($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__cony($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'nif', 'nif', $namespace, 0, 1);	// name="nif" type="nif" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'nom', 'nom', $namespace, 1, 1);	// name="nom" type="nom" minOccurs="1"
  return $myLevel;
}

private function __cde__cony_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__cony($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__repr($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'idr', 'idp', $namespace, 1, 1);	// name="idr" type="idp" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'df', 'dfreps', $namespace, 1, 1);	// name="df" type="dfreps" minOccurs="1"
  return $myLevel;
}

private function __cde__repr_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__repr($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idp($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'nif', 'nif', $namespace, 1, 1);	// name="nif" type="nif" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'nom', 'nom', $namespace, 1, 1);	// name="nom" type="nom" minOccurs="1"
  return $myLevel;
}

private function __cde__idp_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idp($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__dfreps($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'loine', 'loine', $namespace, 1, 1);	// name="loine" type="loine" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'cmc', 'cmc', $namespace, 0, 1);	// name="cmc" type="cmc" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'np', 'np', $namespace, 1, 1);	// name="np" type="np" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'nm', 'nm', $namespace, 1, 1);	// name="nm" type="nm" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'nem', 'nem', $namespace, 0, 1);	// name="nem" type="nem" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dir', 'dir', $namespace, 1, 1);	// name="dir" type="dir" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'loint', 'loint', $namespace, 0, 1);	// name="loint" type="loint" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'pos', 'pos', $namespace, 0, 1);	// name="pos" type="pos" minOccurs="0"
  return $myLevel;
}

private function __cde__dfreps_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__dfreps($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lcol($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'col', 'col', $namespace, 0, unbounded);	// name="col" type="col" minOccurs="0"
  return $myLevel;
}

private function __cde__lcol_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lcol($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__col($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'rcof', 'rcof', $namespace, 0, 1);	// name="rcof" type="rcof" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'idp_out', 'idp_out', $namespace, 0, 1);	// name="idp_out" type="idp_out" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'sup', 'supp', $namespace, 0, 1);	// name="sup" type="supp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'lloc', 'stringnb', $namespace, 0, 1);	// name="lloc" type="stringnb" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dtrus', 'dtrus', $namespace, 0, 1);	// name="dtrus" type="dtrus" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'llind', 'llind', $namespace, 0, 1);	// name="llind" type="llind" minOccurs="0"
  return $myLevel;
}

private function __cde__col_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__col($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__rcof($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  if (isset($vData['rc'])) {
    $this->__doChild($myLevel, $vData, 'rc', 'rc', $namespace, 1, 1);	// name="rc" type="rc" minOccurs="1"
  } elseif (isset($vData['rfin'])) {
    $this->__doChild($myLevel, $vData, 'rfin', 'pc', $namespace, 1, 1);	// name="rfin" type="pc" minOccurs="1"
  } else {
    throw new Exception('Elegir opcion');
  }
  return $myLevel;
}

private function __cde__rcof_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__rcof($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__rc($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'pc1', 'pcatastral1', $namespace, 1, 1);	// name="pc1" type="pcatastral1" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'pc2', 'pcatastral2', $namespace, 1, 1);	// name="pc2" type="pcatastral2" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'car', 'car', $namespace, 1, 1);	// name="car" type="car" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'cc1', 'cc', $namespace, 1, 1);	// name="cc1" type="cc" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'cc2', 'cc', $namespace, 1, 1);	// name="cc2" type="cc" minOccurs="1"
  return $myLevel;
}

private function __cde__rc_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__rc($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__refcat($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $myLevel = $this->__cde__pc($vData, $fieldName, $namespace);
  $this->__doChild($myLevel, $vData, 'car', 'car', $namespace, 0, 1);	// name="car" type="car" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cc1', 'cc', $namespace, 0, 1);	// name="cc1" type="cc" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cc2', 'cc', $namespace, 0, 1);	// name="cc2" type="cc" minOccurs="0"
  return $myLevel;
}

private function __cde__refcat_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__refcat($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idp_out($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'nif', 'nif', $namespace, 0, 1);	// name="nif" type="nif" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'nom', 'nom', $namespace, 0, 1);	// name="nom" type="nom" minOccurs="0"
  return $myLevel;
}

private function __cde__idp_out_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idp_out($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__dtrus($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();

  $fnInt_lorus = function($vData, $fieldName, $namespace)
  {
    $myLevel = new ArrayObject();
    $this->__doChild($myLevel, $vData, 'cma', 'cma', $namespace, 0, 1);	// name="cma" type="cma" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'czc', 'czc', $namespace, 1, 1);	// name="czc" type="czc" minOccurs="1"
    $this->__doChild($myLevel, $vData, 'cpp', 'cpp', $namespace, 1, 1);	// name="cpp" type="cpp" minOccurs="1"
    $this->__doChild($myLevel, $vData, 'npa', 'npa', $namespace, 0, 1);	// name="npa" type="npa" minOccurs="0"
    return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
  };
  $this->__doPrivateChild($myLevel, $vData, 'lorus', $fnInt_lorus, $namespace, 1, 1);	// name="lorus" minOccurs="1"
  return $myLevel;
}

private function __cde__dtrus_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__dtrus($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__llind($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'lind', 'lind', $namespace, 0, 4);	// name="lind" type="lind" minOccurs="0"
  return $myLevel;
}

private function __cde__llind_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__llind($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lind($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'situ', 'situ', $namespace, 1, 1);	// name="situ" type="situ" minOccurs="1"

  $fnInt_loclind = function($vData, $fieldName, $namespace)
  {
    $myLevel = new ArrayObject();

    $fnInt_lourb = function($vData, $fieldName, $namespace)
    {
      $myLevel = new ArrayObject();
      $this->__doChild($myLevel, $vData, 'dir', 'dir', $namespace, 0, 1);	// name="dir" type="dir" minOccurs="0"
      return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    };
    $this->__doPrivateChild($myLevel, $vData, 'lourb', $fnInt_lourb, $namespace, 1, 1);	// name="lourb" minOccurs="1"
    return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
  };
  $this->__doPrivateChild($myLevel, $vData, 'loclind', $fnInt_loclind, $namespace, 1, 1);	// name="loclind" minOccurs="1"
  return $myLevel;
}

private function __cde__lind_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lind($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lcons($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cons', 'cons', $namespace, 0, unbounded);	// name="cons" type="cons" minOccurs="0"
  return $myLevel;
}

private function __cde__lcons_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lcons($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__cons($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'idcons', 'idcons', $namespace, 0, 1);	// name="idcons" type="idcons" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'idconscat', 'idconscat', $namespace, 0, 1);	// name="idconscat" type="idconscat" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'lcd', 'stringnb', $namespace, 0, 1);	// name="lcd" type="stringnb" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dt', 'domi', $namespace, 0, 1);	// name="dt" type="domi" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dte', 'domie', $namespace, 0, 1);	// name="dte" type="domie" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dfcons', 'dfcons', $namespace, 0, 1);	// name="dfcons" type="dfcons" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dvcons', 'dvcons', $namespace, 0, 1);	// name="dvcons" type="dvcons" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'evcons', 'evcons', $namespace, 0, 1);	// name="evcons" type="evcons" minOccurs="0"
  return $myLevel;
}

private function __cde__cons_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__cons($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idcons($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'rcons', 'rcons', $namespace, 1, 1);	// name="rcons" type="rcons" minOccurs="1"
  return $myLevel;
}

private function __cde__idcons_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idcons($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__rcons($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $myLevel = $this->__cde__pc($vData, $fieldName, $namespace);
  $this->__doChild($myLevel, $vData, 'noec', 'noec', $namespace, 1, 1);	// name="noec" type="noec" minOccurs="1"
  return $myLevel;
}

private function __cde__rcons_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__rcons($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idconscat($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $myLevel = $this->__cde__idcons($vData, $fieldName, $namespace);
  $this->__doChild($myLevel, $vData, 'locat', 'locat', $namespace, 1, 1);	// name="locat" type="locat" minOccurs="1"
  return $myLevel;
}

private function __cde__idconscat_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idconscat($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__domi($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();

  $fnInt_lourb = function($vData, $fieldName, $namespace)
  {
    $myLevel = new ArrayObject();
    $this->__doChild($myLevel, $vData, 'loint', 'loint', $namespace, 0, 1);	// name="loint" type="loint" minOccurs="0"
    return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
  };
  $this->__doPrivateChild($myLevel, $vData, 'lourb', $fnInt_lourb, $namespace, 0, 1);	// name="lourb" minOccurs="0"
  return $myLevel;
}

private function __cde__domi_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__domi($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__domie($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'loine', 'loine', $namespace, 1, 1);	// name="loine" type="loine" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'cmc', 'cmc', $namespace, 1, 1);	// name="cmc" type="cmc" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'np', 'np', $namespace, 1, 1);	// name="np" type="np" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'nm', 'nm', $namespace, 1, 1);	// name="nm" type="nm" minOccurs="1"

  $fnInt_lourb = function($vData, $fieldName, $namespace)
  {
    $myLevel = new ArrayObject();
    $this->__doChild($myLevel, $vData, 'loint', 'loint', $namespace, 0, 1);	// name="loint" type="loint" minOccurs="0"
    return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
  };
  $this->__doPrivateChild($myLevel, $vData, 'lourb', $fnInt_lourb, $namespace, 1, 1);	// name="lourb" minOccurs="1"
  return $myLevel;
}

private function __cde__domie_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__domie($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__dfcons($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cuc', 'cuc', $namespace, 0, 1);	// name="cuc" type="cuc" minOccurs="0"
  if (isset($vData['car'])) {
    $this->__doChild($myLevel, $vData, 'car', 'car', $namespace, 1, 1);	// name="car" type="car" minOccurs="1"
  } elseif (isset($vData['modl'])) {
    $this->__doChild($myLevel, $vData, 'modl', 'modl', $namespace, 1, 1);	// name="modl" type="modl" minOccurs="1"
  } else {
    throw new Exception('Elegir opcion');
  }
  $this->__doChild($myLevel, $vData, 'cdes', 'cdes', $namespace, 0, 1);	// name="cdes" type="cdes" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'refor', 'refor', $namespace, 0, 1);	// name="refor" type="refor" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'aec', 'xs:gYear', $namespace, 0, 1);	// name="aec" type="xs:gYear" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ili', 'ie', $namespace, 0, 1);	// name="ili" type="ie" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'stl', 'supp', $namespace, 1, 1);	// name="stl" type="supp" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'spt', 'supp', $namespace, 0, 1);	// name="spt" type="supp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'sil', 'supp', $namespace, 0, 1);	// name="sil" type="supp" minOccurs="0"
  return $myLevel;
}

private function __cde__dfcons_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__dfcons($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__refor($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'tr', 'tr', $namespace, 1, 1);	// name="tr" type="tr" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'ar', 'xs:gYear', $namespace, 1, 1);	// name="ar" type="xs:gYear" minOccurs="1"
  return $myLevel;
}

private function __cde__refor_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__refor($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__dvcons($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'tip', 'tip', $namespace, 1, 1);	// name="tip" type="tip" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'usop', 'uso', $namespace, 1, 1);	// name="usop" type="uso" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'cat', 'cat', $namespace, 1, 1);	// name="cat" type="cat" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'ctv', 'ctvcons', $namespace, 1, 1);	// name="ctv" type="ctvcons" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'ccvscc', 'ccvscc', $namespace, 1, 1);	// name="ccvscc" type="ccvscc" minOccurs="1"
  return $myLevel;
}

private function __cde__dvcons_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__dvcons($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__ccvscc($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'vccad', 'vccad', $namespace, 1, 1);	// name="vccad" type="vccad" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'iacli', 'ie', $namespace, 1, 1);	// name="iacli" type="ie" minOccurs="1"
  return $myLevel;
}

private function __cde__ccvscc_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__ccvscc($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__evcons($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'vrs', 'vur', $namespace, 0, 1);	// name="vrs" type="vur" minOccurs="0"
  if (isset($vData['vmctcc'])) {
    $this->__doChild($myLevel, $vData, 'vmctcc', 'imb1', $namespace, 0, 1);	// name="vmctcc" type="imb1" minOccurs="0"
  } elseif (isset($vData['vmctcb'])) {
    $this->__doChild($myLevel, $vData, 'vmctcb', 'imb2', $namespace, 0, 1);	// name="vmctcb" type="imb2" minOccurs="0"
  } else {
    throw new Exception('Elegir opcion');
  }
  $this->__doChild($myLevel, $vData, 'icca', 'icca', $namespace, 0, 1);	// name="icca" type="icca" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'vtccvs', 'vtcc', $namespace, 0, 1);	// name="vtccvs" type="vtcc" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'vtccvc', 'vtcc', $namespace, 0, 1);	// name="vtccvc" type="vtcc" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'vtccvsc', 'vtcc', $namespace, 0, 1);	// name="vtccvsc" type="vtcc" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ddes', 'desc', $namespace, 0, 1);	// name="ddes" type="desc" minOccurs="0"
  return $myLevel;
}

private function __cde__evcons_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__evcons($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__evbi($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'duso', 'desc', $namespace, 0, 1);	// name="duso" type="desc" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'vcsa', 'vcat', $namespace, 0, 1);	// name="vcsa" type="vcat" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'vcsrc', 'vcat', $namespace, 0, 1);	// name="vcsrc" type="vcat" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ired', 'vcat', $namespace, 0, 1);	// name="ired" type="vcat" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'uared', 'xs:gYear', $namespace, 0, 1);	// name="uared" type="xs:gYear" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'avsa', 'xs:gYear', $namespace, 0, 1);	// name="avsa" type="xs:gYear" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ivcm', 'ia', $namespace, 0, 1);	// name="ivcm" type="ia" minOccurs="0"
  return $myLevel;
}

private function __cde__evbi_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__evbi($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__ltit($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'titular', 'tit', $namespace, 1, unbounded);	// name="titular" type="tit" minOccurs="1"
  return $myLevel;
}

private function __cde__ltit_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__ltit($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__tit($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'der', 'der', $namespace, 0, 1);	// name="der" type="der" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ord', 'ord', $namespace, 0, 1);	// name="ord" type="ord" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'idp', 'idp', $namespace, 0, 1);	// name="idp" type="idp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'idpa', 'idpa', $namespace, 0, 1);	// name="idpa" type="idpa" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'idps', 'idps', $namespace, 0, 1);	// name="idps" type="idps" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'idp_out', 'idp_out', $namespace, 0, 1);	// name="idp_out" type="idp_out" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'lder', 'stringnb', $namespace, 0, 1);	// name="lder" type="stringnb" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'df', 'df', $namespace, 0, 1);	// name="df" type="df" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ldf', 'stringnb', $namespace, 0, 1);	// name="ldf" type="stringnb" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cony', 'idp', $namespace, 0, 1);	// name="cony" type="idp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'idcbf', 'idcbf', $namespace, 0, 1);	// name="idcbf" type="idcbf" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'iatit', 'iatit', $namespace, 0, 1);	// name="iatit" type="iatit" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'rtit', 'rtit', $namespace, 0, 1);	// name="rtit" type="rtit" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'faj', 'fecha', $namespace, 0, 1);	// name="faj" type="fecha" minOccurs="0"
  return $myLevel;
}

private function __cde__tit_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__tit($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__der($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cdr', 'cdr', $namespace, 1, 1);	// name="cdr" type="cdr" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'pct', 'pct', $namespace, 1, 1);	// name="pct" type="pct" minOccurs="1"
  return $myLevel;
}

private function __cde__der_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__der($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idpa($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  if (isset($vData['nif'])) {
    $this->__doChild($myLevel, $vData, 'nif', 'nif', $namespace, 1, 1);	// name="nif" type="nif" minOccurs="1"
  } elseif (isset($vData['anif'])) {
    $this->__doChild($myLevel, $vData, 'anif', 'anif', $namespace, 1, 1);	// name="anif" type="anif" minOccurs="1"
  } else {
    throw new Exception('Elegir opcion');
  }
  $this->__doChild($myLevel, $vData, 'nom', 'nom', $namespace, 1, 1);	// name="nom" type="nom" minOccurs="1"
  return $myLevel;
}

private function __cde__idpa_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idpa($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idcbf($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'nifcb', 'nif', $namespace, 1, 1);	// name="nifcb" type="nif" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'nomcb', 'nomcb', $namespace, 1, 1);	// name="nomcb" type="nomcb" minOccurs="1"
  return $myLevel;
}

private function __cde__idcbf_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idcbf($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__iatit($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'nifcy', 'nif', $namespace, 0, 1);	// name="nifcy" type="nif" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'nifcb', 'nif', $namespace, 0, 1);	// name="nifcb" type="nif" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ct', 'ct', $namespace, 0, 1);	// name="ct" type="ct" minOccurs="0"
  return $myLevel;
}

private function __cde__iatit_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__iatit($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__rtit($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'fit', 'xs:date', $namespace, 1, 1);	// name="fit" type="xs:date" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'fft', 'xs:date', $namespace, 1, 1);	// name="fft" type="xs:date" minOccurs="1"
  return $myLevel;
}

private function __cde__rtit_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__rtit($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__fincared($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'ldt', 'stringnb', $namespace, 0, 1);	// name="ldt" type="stringnb" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ltp', 'stringnb', $namespace, 0, 1);	// name="ltp" type="stringnb" minOccurs="0"

  $fnInt_dff = function($vData, $fieldName, $namespace)
  {
    $myLevel = new ArrayObject();

    $fnInt_ssf = function($vData, $fieldName, $namespace)
    {
      $myLevel = new ArrayObject();
      $this->__doChild($myLevel, $vData, 'ss', 'supg', $namespace, 1, 1);	// name="ss" type="supg" minOccurs="1"
      $this->__doChild($myLevel, $vData, 'sct', 'supp', $namespace, 1, 1);	// name="sct" type="supp" minOccurs="1"
      return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    };
    $this->__doPrivateChild($myLevel, $vData, 'ssf', $fnInt_ssf, $namespace, 0, 1);	// name="ssf" minOccurs="0"
    return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
  };
  $this->__doPrivateChild($myLevel, $vData, 'dff', $fnInt_dff, $namespace, 0, 1);	// name="dff" minOccurs="0"

  $fnInt_infgraf = function($vData, $fieldName, $namespace)
  {
    $myLevel = new ArrayObject();
    $this->__doChild($myLevel, $vData, 'esc', 'xs:integer', $namespace, 0, 1);	// name="esc" type="xs:integer" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'igraf', 'stringnb', $namespace, 0, 1);	// name="igraf" type="stringnb" minOccurs="0"
    return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
  };
  $this->__doPrivateChild($myLevel, $vData, 'infgraf', $fnInt_infgraf, $namespace, 0, 1);	// name="infgraf" minOccurs="0"
  return $myLevel;
}

private function __cde__fincared_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__fincared($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__finca($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'idf', 'idf', $namespace, 0, 1);	// name="idf" type="idf" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'idfcat', 'idfcat', $namespace, 0, 1);	// name="idfcat" type="idfcat" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'rbice', 'rbice', $namespace, 0, 1);	// name="rbice" type="rbice" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dt', 'dtr', $namespace, 0, 1);	// name="dt" type="dtr" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ldt', 'stringnb', $namespace, 0, 1);	// name="ldt" type="stringnb" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ltp', 'stringnb', $namespace, 0, 1);	// name="ltp" type="stringnb" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dff', 'dff', $namespace, 0, 1);	// name="dff" type="dff" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dval', 'dval', $namespace, 0, 1);	// name="dval" type="dval" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'planta', 'planta', $namespace, 0, 1);	// name="planta" type="planta" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'infgraf', 'infgraf', $namespace, 0, 1);	// name="infgraf" type="infgraf" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'evf', 'evf', $namespace, 0, 1);	// name="evf" type="evf" minOccurs="0"
  return $myLevel;
}

private function __cde__finca_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__finca($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idf($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cn', 'cnf', $namespace, 0, 1);	// name="cn" type="cnf" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'pc', 'pc', $namespace, 1, 1);	// name="pc" type="pc" minOccurs="1"
  return $myLevel;
}

private function __cde__idf_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idf($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idfcat($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $myLevel = $this->__cde__idf($vData, $fieldName, $namespace);
  $this->__doChild($myLevel, $vData, 'locat', 'locat', $namespace, 1, 1);	// name="locat" type="locat" minOccurs="1"
  return $myLevel;
}

private function __cde__idfcat_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idfcat($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__rbice($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'rc', 'rc', $namespace, 1, 1);	// name="rc" type="rc" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'desb', 'desb', $namespace, 1, 1);	// name="desb" type="desb" minOccurs="1"
  return $myLevel;
}

private function __cde__rbice_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__rbice($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__dtr($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'loine', 'loine', $namespace, 1, 1);	// name="loine" type="loine" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'cmc', 'cmc', $namespace, 1, 1);	// name="cmc" type="cmc" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'np', 'np', $namespace, 1, 1);	// name="np" type="np" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'nm', 'nm', $namespace, 1, 1);	// name="nm" type="nm" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'nem', 'nem', $namespace, 0, 1);	// name="nem" type="nem" minOccurs="0"

  $fnInt_locs = function($vData, $fieldName, $namespace)
  {
    $myLevel = new ArrayObject();
    if (isset($vData['lous'])) {
      $this->__doChild($myLevel, $vData, 'lous', 'lousf', $namespace, 1, 1);	// name="lous" type="lousf" minOccurs="1"
    } elseif (isset($vData['lors'])) {
      $this->__doChild($myLevel, $vData, 'lors', 'lorsf', $namespace, 1, 1);	// name="lors" type="lorsf" minOccurs="1"
    } else {
      throw new Exception('Elegir opcion');
    }
    return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
  };
  $this->__doPrivateChild($myLevel, $vData, 'locs', $fnInt_locs, $namespace, 1, 1);	// name="locs" minOccurs="1"
  return $myLevel;
}

private function __cde__dtr_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__dtr($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lousf($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'lourb', 'lourbf', $namespace, 1, 1);	// name="lourb" type="lourbf" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'lorus', 'lorusf', $namespace, 0, 1);	// name="lorus" type="lorusf" minOccurs="0"
  return $myLevel;
}

private function __cde__lousf_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lousf($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lourbf($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();

  $fnInt_dir = function($vData, $fieldName, $namespace)
  {
    $myLevel = new ArrayObject();
    $this->__doChild($myLevel, $vData, 'cv', 'cv', $namespace, 1, 1);	// name="cv" type="cv" minOccurs="1"
    $this->__doChild($myLevel, $vData, 'tv', 'tv', $namespace, 1, 1);	// name="tv" type="tv" minOccurs="1"
    $this->__doChild($myLevel, $vData, 'nv', 'nv', $namespace, 1, 1);	// name="nv" type="nv" minOccurs="1"
    $this->__doChild($myLevel, $vData, 'pnp', 'pnp', $namespace, 0, 1);	// name="pnp" type="pnp" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'plp', 'plp', $namespace, 0, 1);	// name="plp" type="plp" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'snp', 'snp', $namespace, 0, 1);	// name="snp" type="snp" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'slp', 'slp', $namespace, 0, 1);	// name="slp" type="slp" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'km', 'km', $namespace, 0, 1);	// name="km" type="km" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'td', 'dne', $namespace, 0, 1);	// name="td" type="dne" minOccurs="0"
    return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
  };
  $this->__doPrivateChild($myLevel, $vData, 'dir', $fnInt_dir, $namespace, 1, 1);	// name="dir" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'bl', 'bq', $namespace, 0, 1);	// name="bl" type="bq" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dp', 'dp', $namespace, 0, 1);	// name="dp" type="dp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dm', 'dm', $namespace, 0, 1);	// name="dm" type="dm" minOccurs="0"
  return $myLevel;
}

private function __cde__lourbf_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lourbf($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lorusf($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cma', 'cma', $namespace, 0, 1);	// name="cma" type="cma" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'czc', 'czc', $namespace, 0, 1);	// name="czc" type="czc" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cpp', 'cpp', $namespace, 1, 1);	// name="cpp" type="cpp" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'npa', 'npa', $namespace, 0, 1);	// name="npa" type="npa" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cpaj', 'cpaj', $namespace, 0, 1);	// name="cpaj" type="cpaj" minOccurs="0"
  return $myLevel;
}

private function __cde__lorusf_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lorusf($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lorsf($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'lorus', 'lorusfop', $namespace, 1, 1);	// name="lorus" type="lorusfop" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'lourb', 'lourbfr', $namespace, 0, 1);	// name="lourb" type="lourbfr" minOccurs="0"
  return $myLevel;
}

private function __cde__lorsf_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lorsf($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lorusfop($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cma', 'cma', $namespace, 0, 1);	// name="cma" type="cma" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'czc', 'czc', $namespace, 0, 1);	// name="czc" type="czc" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cpp', 'cpp', $namespace, 1, 1);	// name="cpp" type="cpp" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'npa', 'npa', $namespace, 1, 1);	// name="npa" type="npa" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'cpaj', 'cpaj', $namespace, 1, 1);	// name="cpaj" type="cpaj" minOccurs="1"
  return $myLevel;
}

private function __cde__lorusfop_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lorusfop($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lourbfr($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();

  $fnInt_dir = function($vData, $fieldName, $namespace)
  {
    $myLevel = new ArrayObject();
    $this->__doChild($myLevel, $vData, 'cv', 'cv', $namespace, 1, 1);	// name="cv" type="cv" minOccurs="1"
    $this->__doChild($myLevel, $vData, 'tv', 'tv', $namespace, 1, 1);	// name="tv" type="tv" minOccurs="1"
    $this->__doChild($myLevel, $vData, 'nv', 'nv', $namespace, 1, 1);	// name="nv" type="nv" minOccurs="1"
    $this->__doChild($myLevel, $vData, 'pnp', 'pnp', $namespace, 0, 1);	// name="pnp" type="pnp" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'plp', 'plp', $namespace, 0, 1);	// name="plp" type="plp" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'snp', 'snp', $namespace, 0, 1);	// name="snp" type="snp" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'slp', 'slp', $namespace, 0, 1);	// name="slp" type="slp" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'km', 'km', $namespace, 0, 1);	// name="km" type="km" minOccurs="0"
    $this->__doChild($myLevel, $vData, 'td', 'dne', $namespace, 0, 1);	// name="td" type="dne" minOccurs="0"
    return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
  };
  $this->__doPrivateChild($myLevel, $vData, 'dir', $fnInt_dir, $namespace, 0, 1);	// name="dir" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'bl', 'bq', $namespace, 0, 1);	// name="bl" type="bq" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dp', 'dp', $namespace, 0, 1);	// name="dp" type="dp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dm', 'dm', $namespace, 0, 1);	// name="dm" type="dm" minOccurs="0"
  return $myLevel;
}

private function __cde__lourbfr_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lourbfr($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__dff($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'ssf', 'ssf', $namespace, 0, 1);	// name="ssf" type="ssf" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cen', 'cen', $namespace, 0, 1);	// name="cen" type="cen" minOccurs="0"
  return $myLevel;
}

private function __cde__dff_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__dff($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__ssf($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'ss', 'supg', $namespace, 0, 1);	// name="ss" type="supg" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'sct', 'supp', $namespace, 0, 1);	// name="sct" type="supp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ssr', 'supp', $namespace, 0, 1);	// name="ssr" type="supp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'sbr', 'supp', $namespace, 0, 1);	// name="sbr" type="supp" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'sc', 'supp', $namespace, 0, 1);	// name="sc" type="supp" minOccurs="0"
  return $myLevel;
}

private function __cde__ssf_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__ssf($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__cen($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'coordx', 'coordx', $namespace, 1, 1);	// name="coordx" type="coordx" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'coordy', 'coordy', $namespace, 1, 1);	// name="coordy" type="coordy" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'srs', 'hg', $namespace, 1, 1);	// name="srs" type="hg" minOccurs="1"
  return $myLevel;
}

private function __cde__cen_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__cen($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__dval($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'aapv', 'xs:gYear', $namespace, 1, 1);	// name="aapv" type="xs:gYear" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'cfcvc', 'cfcvc', $namespace, 1, 1);	// name="cfcvc" type="cfcvc" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'cpo', 'cpov', $namespace, 1, 1);	// name="cpo" type="cpov" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'mr', 'mr', $namespace, 1, 1);	// name="mr" type="mr" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'iipvc', 'iipvc', $namespace, 0, 1);	// name="iipvc" type="iipvc" minOccurs="0"
  return $myLevel;
}

private function __cde__dval_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__dval($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__planta($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'nps', 'nps', $namespace, 1, 1);	// name="nps" type="nps" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'lplan', 'lplan', $namespace, 1, 1);	// name="lplan" type="lplan" minOccurs="1"
  return $myLevel;
}

private function __cde__planta_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__planta($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lplan($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();

  $fnInt_plansig = function($vData, $fieldName, $namespace)
  {
    $myLevel = new ArrayObject();
    $this->__doChild($myLevel, $vData, 'npss', 'npss', $namespace, 1, 1);	// name="npss" type="npss" minOccurs="1"
    $this->__doChild($myLevel, $vData, 'npsig', 'npsig', $namespace, 1, 1);	// name="npsig" type="npsig" minOccurs="1"
    $this->__doChild($myLevel, $vData, 'nd', 'nd', $namespace, 1, 1);	// name="nd" type="nd" minOccurs="1"

    $fnInt_ld = function($vData, $fieldName, $namespace)
    {
      $myLevel = new ArrayObject();

      $fnInt_dest = function($vData, $fieldName, $namespace)
      {
        $myLevel = new ArrayObject();
        $this->__doChild($myLevel, $vData, 'cd', 'cdest', $namespace, 1, 1);	// name="cd" type="cdest" minOccurs="1"
        $this->__doChild($myLevel, $vData, 'supd', 'supd', $namespace, 1, 1);	// name="supd" type="supd" minOccurs="1"
        return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
      };
      $this->__doPrivateChild($myLevel, $vData, 'dest', $fnInt_dest, $namespace, 1, 1);	// name="dest" minOccurs="1"
      return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
    };
    $this->__doPrivateChild($myLevel, $vData, 'ld', $fnInt_ld, $namespace, 1, 1);	// name="ld" minOccurs="1"
    return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
  };
  $this->__doPrivateChild($myLevel, $vData, 'plansig', $fnInt_plansig, $namespace, 1, 1);	// name="plansig" minOccurs="1"
  return $myLevel;
}

private function __cde__lplan_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lplan($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__infgraf($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'esc', 'xs:integer', $namespace, 0, 1);	// name="esc" type="xs:integer" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'fech', 'xs:date', $namespace, 0, 1);	// name="fech" type="xs:date" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'igraf', 'stringnb', $namespace, 0, 1);	// name="igraf" type="stringnb" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'graf', 'xs:base64Binary', $namespace, 0, 1);	// name="graf" type="xs:base64Binary" minOccurs="0"
  return $myLevel;
}

private function __cde__infgraf_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__infgraf($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__evf($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'mbc', 'imb1', $namespace, 0, 1);	// name="mbc" type="imb1" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'mbrs', 'imb1', $namespace, 0, 1);	// name="mbrs" type="imb1" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'mbcci', 'imb1', $namespace, 0, 1);	// name="mbcci" type="imb1" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'mbrcni', 'imb1', $namespace, 0, 1);	// name="mbrcni" type="imb1" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'mbrci', 'imb1', $namespace, 0, 1);	// name="mbrci" type="imb1" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'vuzc', 'vur', $namespace, 0, 1);	// name="vuzc" type="vur" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'vup', 'vur', $namespace, 0, 1);	// name="vup" type="vur" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'vrp', 'vur', $namespace, 0, 1);	// name="vrp" type="vur" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'gb', 'gb', $namespace, 0, 1);	// name="gb" type="gb" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'nbop', 'nbo', $namespace, 0, 1);	// name="nbop" type="nbo" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'fbop', 'fecha', $namespace, 0, 1);	// name="fbop" type="fecha" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'nbovm', 'nbo', $namespace, 0, 1);	// name="nbovm" type="nbo" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'fbovm', 'fecha', $namespace, 0, 1);	// name="fbovm" type="fecha" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'aantv', 'xs:gYear', $namespace, 0, 1);	// name="aantv" type="xs:gYear" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'gntv', 'gntv', $namespace, 0, 1);	// name="gntv" type="gntv" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'fboom', 'fecha', $namespace, 0, 1);	// name="fboom" type="fecha" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'nboom', 'nbo', $namespace, 0, 1);	// name="nboom" type="nbo" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cicir', 'cicir', $namespace, 0, 1);	// name="cicir" type="cicir" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'mbpe', 'imb2', $namespace, 0, 1);	// name="mbpe" type="imb2" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'mbpg', 'imb2', $namespace, 0, 1);	// name="mbpg" type="imb2" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'mbpr', 'imb2', $namespace, 0, 1);	// name="mbpr" type="imb2" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'mcua', 'imb2', $namespace, 0, 1);	// name="mcua" type="imb2" minOccurs="0"
  return $myLevel;
}

private function __cde__evf_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__evf($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__ccgu($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'agu', 'coefc', $namespace, 1, 1);	// name="agu" type="coefc" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'elec', 'coefc', $namespace, 1, 1);	// name="elec" type="coefc" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'alum', 'coefc', $namespace, 1, 1);	// name="alum" type="coefc" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'des', 'coefc', $namespace, 1, 1);	// name="des" type="coefc" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'pav', 'coefc', $namespace, 1, 1);	// name="pav" type="coefc" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'alc', 'coefc', $namespace, 1, 1);	// name="alc" type="coefc" minOccurs="1"
  return $myLevel;
}

private function __cde__ccgu_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__ccgu($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lconsr($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'construccion', 'consr', $namespace, 1, unbounded);	// name="construccion" type="consr" minOccurs="1"
  return $myLevel;
}

private function __cde__lconsr_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lconsr($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__consr($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'lcd', 'stringnb', $namespace, 1, 1);	// name="lcd" type="stringnb" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'dt', 'domi', $namespace, 1, 1);	// name="dt" type="domi" minOccurs="1"

  $fnInt_dfcons = function($vData, $fieldName, $namespace)
  {
    $myLevel = new ArrayObject();
    $this->__doChild($myLevel, $vData, 'stl', 'supp', $namespace, 1, 1);	// name="stl" type="supp" minOccurs="1"
    return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
  };
  $this->__doPrivateChild($myLevel, $vData, 'dfcons', $fnInt_dfcons, $namespace, 0, 1);	// name="dfcons" minOccurs="0"
  return $myLevel;
}

private function __cde__consr_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__consr($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__lspr($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'subparcela', 'sprr', $namespace, 1, unbounded);	// name="subparcela" type="sprr" minOccurs="1"
  return $myLevel;
}

private function __cde__lspr_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__lspr($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__sprr($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cspr', 'cspr', $namespace, 1, 1);	// name="cspr" type="cspr" minOccurs="1"

  $fnInt_dspr = function($vData, $fieldName, $namespace)
  {
    $myLevel = new ArrayObject();
    $this->__doChild($myLevel, $vData, 'ccc', 'ccc', $namespace, 1, 1);	// name="ccc" type="ccc" minOccurs="1"
    $this->__doChild($myLevel, $vData, 'dcc', 'dcc', $namespace, 1, 1);	// name="dcc" type="dcc" minOccurs="1"
    $this->__doChild($myLevel, $vData, 'ip', 'ip', $namespace, 1, 1);	// name="ip" type="ip" minOccurs="1"
    $this->__doChild($myLevel, $vData, 'ssp', 'supg', $namespace, 1, 1);	// name="ssp" type="supg" minOccurs="1"
    $this->__doChild($myLevel, $vData, 'vsp', 'vcat', $namespace, 1, 1);	// name="vsp" type="vcat" minOccurs="1"
    return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
  };
  $this->__doPrivateChild($myLevel, $vData, 'dspr', $fnInt_dspr, $namespace, 1, 1);	// name="dspr" minOccurs="1"
  return $myLevel;
}

private function __cde__sprr_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__sprr($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__spr($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'idspr', 'idspr', $namespace, 0, 1);	// name="idspr" type="idspr" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'cspr', 'cspr', $namespace, 0, 1);	// name="cspr" type="cspr" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dspr', 'dspr', $namespace, 0, 1);	// name="dspr" type="dspr" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'evspr', 'evspr', $namespace, 0, 1);	// name="evspr" type="evspr" minOccurs="0"
  return $myLevel;
}

private function __cde__spr_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__spr($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__idspr($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $myLevel = $this->__cde__pc($vData, $fieldName, $namespace);
  $this->__doChild($myLevel, $vData, 'cn', 'cn', $namespace, 1, 1);	// name="cn" type="cn" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'cspr', 'cspr', $namespace, 1, 1);	// name="cspr" type="cspr" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'ccc', 'ccc', $namespace, 1, 1);	// name="ccc" type="ccc" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'locat', 'locat', $namespace, 1, 1);	// name="locat" type="locat" minOccurs="1"
  return $myLevel;
}

private function __cde__idspr_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__idspr($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__dspr($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  if (isset($vData['car'])) {
    $this->__doChild($myLevel, $vData, 'car', 'car', $namespace, 0, 1);	// name="car" type="car" minOccurs="0"
  } elseif (isset($vData['modl'])) {
    $this->__doChild($myLevel, $vData, 'modl', 'modlspr', $namespace, 1, 1);	// name="modl" type="modlspr" minOccurs="1"
  } else {
    throw new Exception('Elegir opcion');
  }
  $this->__doChild($myLevel, $vData, 'ccc', 'ccc', $namespace, 0, 1);	// name="ccc" type="ccc" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'tspr', 'tspr', $namespace, 0, 1);	// name="tspr" type="tspr" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'dcc', 'dcc', $namespace, 0, 1);	// name="dcc" type="dcc" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ip', 'ip', $namespace, 0, 1);	// name="ip" type="ip" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'ssp', 'supg', $namespace, 1, 1);	// name="ssp" type="supg" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'bspr', 'bspr', $namespace, 0, 1);	// name="bspr" type="bspr" minOccurs="0"
  $this->__doChild($myLevel, $vData, 'vsp', 'vcat', $namespace, 0, 1);	// name="vsp" type="vcat" minOccurs="0"
  return $myLevel;
}

private function __cde__dspr_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__dspr($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__bspr($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'cbspr', 'cbspr', $namespace, 1, 1);	// name="cbspr" type="cbspr" minOccurs="1"
  $this->__doChild($myLevel, $vData, 'efb', 'xs:gYear', $namespace, 0, 1);	// name="efb" type="xs:gYear" minOccurs="0"
  return $myLevel;
}

private function __cde__bspr_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__bspr($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private function __cde__evspr($vData, $fieldName, $namespace)
{
  $myLevel = new ArrayObject();
  $this->__doChild($myLevel, $vData, 'te', 'te', $namespace, 0, 1);	// name="te" type="te" minOccurs="0"
  return $myLevel;
}

private function __cde__evspr_full($vData, $fieldName, $namespace)
{
  $myLevel = $this->__cde__evspr($vData, $fieldName, $namespace);
  return new SoapVar($myLevel, SOAP_ENC_OBJECT, null, null, $fieldName, $namespace);
}



private $vBasics = array('te' => 101, 'cbspr' => 101, 'ip' => 131, 'dcc' => 101, 'tspr' => 101, 'modlspr' => 101, 'ccc' => 101, 'cspr' => 101, 'cicir' => 101, 'gntv' => 101, 'nbo' => 131, 'gb' => 101, 'coefc' => 101, 'supd' => 131, 'cdest' => 101, 'nd' => 131, 'npsig' => 101, 'npss' => 131, 'nps' => 131, 'iipvc' => 101, 'mr' => 101, 'cpov' => 101, 'cfcvc' => 101, 'hg' => 101, 'coordy' => 101, 'coordx' => 101, 'desb' => 101, 'cnf' => 101, 'fecha' => 109, 'nomcb' => 101, 'anif' => 101, 'ord' => 131, 'pct' => 101, 'cdr' => 101, 'lusoovccd' => 101, 'ia' => 101, 'desc' => 101, 'vtcc' => 101, 'icca' => 101, 'imb2' => 101, 'imb1' => 101, 'vur' => 101, 'vccad' => 101, 'ctvcons' => 101, 'cat' => 101, 'tip' => 101, 'ie' => 101, 'tr' => 101, 'cdes' => 101, 'modl' => 101, 'cuc' => 101, 'noec' => 101, 'situ' => 101, 'supp' => 101, 'ac' => 101, 'nom' => 101, 'cii' => 101, 'nif' => 101, 'ct' => 101, 'tt' => 131, 'nt' => 131, 'dr' => 101, 'per' => 131, 'cvb' => 101, 'cpt' => 101, 'supg' => 101, 'cbon' => 101, 'luso' => 101, 'uso' => 101, 'noe' => 101, 'itp' => 101, 'opvd' => 101, 'vcat' => 101, 'tnfr' => 101, 'tcons' => 101, 'ciur' => 101, 'sup' => 131, 'cpaj' => 101, 'npa' => 101, 'cma' => 101, 'czc' => 101, 'dm' => 101, 'dp' => 101, 'es' => 101, 'pt' => 101, 'pu' => 101, 'bq' => 101, 'dne' => 101, 'plp' => 101, 'snp' => 101, 'slp' => 101, 'km' => 101, 'pnp' => 101, 'nv' => 101, 'tv' => 101, 'cv' => 101, 'nem' => 101, 'nm' => 101, 'np' => 101, 'tbi' => 101, 'noedh' => 101, 'sfr' => 101, 'fr' => 101, 'sc' => 101, 'crp' => 101, 'iia' => 101, 'nfbi' => 101, 'irc' => 101, 'erc' => 101, 'lrc' => 101, 'cmc' => 131, 'cd' => 131, 'cn' => 101, 'stringnmb' => 101, 'stringnb' => 101, 'cp' => 101, 'cm' => 101, 'cpo' => 101, 'cpa' => 101, 'pcatastral1' => 101, 'pcatastral2' => 101, 'car' => 101, 'cc' => 101, 'xs:string' => 101, 'xs:int' => 135, 'xs:integer' => 131, 'xs:date' => 109, 'xs:gYear' => 111, 'xs:base64Binary' => 116);
}
?>